@@ -1,4 +1,4 @@
-mod buildin;
+mod builtin;
 mod findpackage;
 mod includescanner;
 use crate::consts::TREESITTER_CMAKE_LANGUAGE;
@@ -8,9 +8,9 @@ use crate::scansubs::TREE_MAP;
 use crate::utils::treehelper::{get_pos_type, PositionType, ToPoint};
 use crate::utils::{
     gen_module_pattern, include_is_module, remove_quotation_and_replace_placeholders,
-    LineCommentTmp, CACHE_CMAKE_PACKAGES_WITHKEYS,
+    DocumentNormalize, LineCommentTmp, CACHE_CMAKE_PACKAGES_WITHKEYS,
 };
-use buildin::{BUILDIN_COMMAND, BUILDIN_MODULE, BUILDIN_VARIABLE};
+use builtin::{BUILTIN_COMMAND, BUILTIN_MODULE, BUILTIN_VARIABLE};
 use std::collections::HashMap;
 use std::path::{Path, PathBuf};
 use std::sync::Arc;
@@ -52,9 +52,10 @@ pub fn rst_doc_read(doc: &str, filename: &str) -> Vec<CompletionItem> {
 }
 
 pub async fn update_cache<P: AsRef<Path>>(path: P, context: &str) -> Vec<CompletionItem> {
+    let context = context.normalize();
     let mut parse = tree_sitter::Parser::new();
     parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
-    let thetree = parse.parse(context, None);
+    let thetree = parse.parse(&context, None);
     let tree = thetree.unwrap();
     let Some(result_data) = getsubcomplete(
         tree.root_node(),
@@ -103,21 +104,23 @@ pub async fn get_cached_completion<P: AsRef<Path>>(path: P) -> Vec<CompletionIte
 }
 
 /// get the complete messages
-pub async fn getcomplete(
+pub async fn getcomplete<P: AsRef<Path>>(
     source: &str,
     location: Position,
     client: &tower_lsp::Client,
-    local_path: &str,
+    local_path: P,
     find_cmake_in_package: bool,
 ) -> Option<CompletionResponse> {
+    let local_path = local_path.as_ref();
+    let source = source.normalize();
     let mut parse = tree_sitter::Parser::new();
     parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
-    let thetree = parse.parse(source, None);
+    let thetree = parse.parse(&source, None);
     let tree = thetree.unwrap();
     let mut complete: Vec<CompletionItem> = vec![];
 
     let current_point = location.to_point();
-    let postype = get_pos_type(current_point, tree.root_node(), source);
+    let postype = get_pos_type(current_point, tree.root_node(), &source);
     match postype {
         PositionType::VarOrFun | PositionType::TargetLink | PositionType::TargetInclude => {
             let mut cached_compeletion = get_cached_completion(local_path).await;
@@ -141,10 +144,10 @@ pub async fn getcomplete(
                 complete.append(&mut message);
             }
 
-            if let Ok(messages) = &*BUILDIN_COMMAND {
+            if let Ok(messages) = &*BUILTIN_COMMAND {
                 complete.append(&mut messages.clone());
             }
-            if let Ok(messages) = &*BUILDIN_VARIABLE {
+            if let Ok(messages) = &*BUILTIN_VARIABLE {
                 complete.append(&mut messages.clone());
             }
         }
@@ -166,7 +169,7 @@ pub async fn getcomplete(
             if let Some(mut cmake_cache) = fileapi::get_complete_data() {
                 complete.append(&mut cmake_cache);
             }
-            if let Ok(messages) = &*BUILDIN_MODULE {
+            if let Ok(messages) = &*BUILTIN_MODULE {
                 complete.append(&mut messages.clone());
             }
         }
@@ -214,8 +217,8 @@ fn getsubcomplete<P: AsRef<Path>>(
     let mut course = input.walk();
     let mut complete: Vec<CompletionItem> = vec![];
     let mut line_comment_tmp = LineCommentTmp {
-        start_y: 0,
-        comment: "",
+        end_y: 0,
+        comments: vec![],
     };
     for child in input.children(&mut course) {
         if let Some(location) = location {
@@ -226,12 +229,18 @@ fn getsubcomplete<P: AsRef<Path>>(
         }
         match child.kind() {
             CMakeNodeKinds::LINE_COMMENT => {
-                let start_y = child.start_position().row;
                 let start_x = child.start_position().column;
                 let end_x = child.end_position().column;
-                line_comment_tmp = LineCommentTmp {
-                    start_y,
-                    comment: &source[start_y][start_x..end_x],
+                let end_y = child.end_position().row;
+                let comment = &source[end_y][start_x..end_x];
+                if end_y - line_comment_tmp.end_y == 1 {
+                    line_comment_tmp.end_y = end_y;
+                    line_comment_tmp.comments.push(comment);
+                } else {
+                    line_comment_tmp = LineCommentTmp {
+                        end_y,
+                        comments: vec![comment],
+                    }
                 }
             }
             CMakeNodeKinds::BRACKET_COMMENT => {
@@ -337,7 +346,7 @@ fn getsubcomplete<P: AsRef<Path>>(
                         else {
                             continue;
                         };
-                        let (is_buildin, subpath) = {
+                        let (is_builtin, subpath) = {
                             if !include_is_module(&name) {
                                 (false, local_path.parent().unwrap().join(name))
                             } else {
@@ -365,7 +374,7 @@ fn getsubcomplete<P: AsRef<Path>>(
                                 include_files,
                                 complete_packages,
                                 find_cmake_in_package,
-                                is_buildin,
+                                is_builtin,
                             ) {
                                 complete.append(&mut comps);
                             }
@@ -863,15 +872,15 @@ Example using both :command:`configure_package_config_file` and
 #[test]
 fn comment_mark_test() {
     let temp = LineCommentTmp {
-        start_y: 1,
-        comment: "",
+        end_y: 1,
+        comments: vec![],
     };
 
     assert!(!temp.is_node_comment(2));
 
     let temp = LineCommentTmp {
-        start_y: 1,
-        comment: "# ABCD",
+        end_y: 1,
+        comments: vec!["# ABCD"],
     };
     assert!(temp.is_node_comment(2));
     assert!(!temp.is_node_comment(1));
@@ -962,3 +971,83 @@ endfunction()
         ]
     );
 }
+
+#[test]
+fn test_complete_win() {
+    use std::fs::File;
+    use std::io::Write;
+    use tempfile::tempdir;
+
+    let file_info = "set(AB \"100\")\r\n# test hello \r\nfunction(bb)\r\nendfunction()".normalize();
+
+    let mut parse = tree_sitter::Parser::new();
+    parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
+    let thetree = parse.parse(&file_info, None).unwrap();
+    let dir = tempdir().unwrap();
+    let root_cmake = dir.path().join("CMakeList.txt");
+    let mut file = File::create(&root_cmake).unwrap();
+    writeln!(file, "{}", &file_info).unwrap();
+    let data = getsubcomplete(
+        thetree.root_node(),
+        &file_info.lines().collect(),
+        &root_cmake,
+        PositionType::VarOrFun,
+        None,
+        &mut vec![],
+        &mut vec![],
+        false,
+        false,
+    )
+    .unwrap();
+    assert_eq!(
+        data,
+        vec![
+            CompletionItem {
+                label: "AB".to_string(),
+                label_details: None,
+                kind: Some(CompletionItemKind::VALUE),
+                detail: Some("Value".to_string()),
+                documentation: Some(Documentation::String(format!(
+                    "defined variable\nfrom: {}",
+                    root_cmake.display()
+                ))),
+                deprecated: None,
+                preselect: None,
+                sort_text: None,
+                filter_text: None,
+                insert_text: None,
+                insert_text_format: None,
+                insert_text_mode: None,
+                text_edit: None,
+                additional_text_edits: None,
+                command: None,
+                commit_characters: None,
+                data: None,
+                tags: None
+            },
+            CompletionItem {
+                label: "bb".to_string(),
+                label_details: None,
+                kind: Some(CompletionItemKind::FUNCTION),
+                detail: Some("Function".to_string()),
+                documentation: Some(Documentation::String(format!(
+                    "defined function\nfrom: {}\n\ntest hello",
+                    root_cmake.display()
+                ))),
+                deprecated: None,
+                preselect: None,
+                sort_text: None,
+                filter_text: None,
+                insert_text: None,
+                insert_text_format: None,
+                insert_text_mode: None,
+                text_edit: None,
+                additional_text_edits: None,
+                command: None,
+                commit_characters: None,
+                data: None,
+                tags: None
+            }
+        ]
+    );
+}
