@@ -18,6 +18,13 @@ static FIND_PACKAGE_SPACE_KEYWORDS: LazyLock<Vec<CompletionItem>> = LazyLock::ne
             documentation: None,
             ..Default::default()
         },
+        CompletionItem {
+            label: "CONFIG".to_string(),
+            kind: Some(CompletionItemKind::KEYWORD),
+            detail: Some("set the config of the packages".to_string()),
+            documentation: None,
+            ..Default::default()
+        },
     ]
 });
 
@@ -42,7 +49,7 @@ static PKGCONFIG_KEYWORDS: LazyLock<Vec<CompletionItem>> = LazyLock::new(|| {
 });
 
 pub static CMAKE_SOURCE: LazyLock<Vec<CompletionItem>> = LazyLock::new(|| {
-    CACHE_CMAKE_PACKAGES
+    let mut data: Vec<CompletionItem> = CACHE_CMAKE_PACKAGES
         .iter()
         .map(|package| CompletionItem {
             label: package.name.clone(),
@@ -60,7 +67,9 @@ pub static CMAKE_SOURCE: LazyLock<Vec<CompletionItem>> = LazyLock::new(|| {
             })),
             ..Default::default()
         })
-        .collect()
+        .collect();
+    data.append(&mut FIND_PACKAGE_SPACE_KEYWORDS.clone());
+    data
 });
 
 pub(super) fn completion_items_with_prefix(space: &str) -> Vec<CompletionItem> {
