@@ -1,4 +1,7 @@
-use crate::{consts::TREESITTER_CMAKE_LANGUAGE, utils::treehelper::PositionType};
+use crate::{
+    consts::TREESITTER_CMAKE_LANGUAGE,
+    utils::{treehelper::PositionType, DocumentNormalize},
+};
 
 use super::getsubcomplete;
 use std::collections::HashMap;
@@ -21,16 +24,16 @@ pub fn scanner_include_complete(
     include_files: &mut Vec<PathBuf>,
     complete_packages: &mut Vec<String>,
     find_cmake_in_package: bool,
-    is_buildin: bool,
+    is_builtin: bool,
 ) -> Option<Vec<CompletionItem>> {
-    if is_buildin {
+    if is_builtin {
         if let Ok(cache) = PACKAGE_COMPLETE_CACHE.lock() {
             if let Some(complete_items) = cache.get(path) {
                 return Some(complete_items.clone());
             }
         }
     }
-    let content = fs::read_to_string(path).ok()?;
+    let content = fs::read_to_string(path).ok()?.normalize();
     let mut parse = tree_sitter::Parser::new();
     parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
     let tree = parse.parse(content.clone(), None)?;
@@ -45,7 +48,7 @@ pub fn scanner_include_complete(
         true,
         find_cmake_in_package,
     );
-    if !is_buildin {
+    if !is_builtin {
         return result_data;
     }
     if let Some(ref content) = result_data {
@@ -67,7 +70,7 @@ pub fn scanner_package_complete(
             return Some(complete_items.clone());
         }
     }
-    let content = fs::read_to_string(path).ok()?;
+    let content = fs::read_to_string(path).ok()?.normalize();
     let mut parse = tree_sitter::Parser::new();
     parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
     let tree = parse.parse(&content, None)?;
