@@ -3,7 +3,7 @@ use lsp_types::Url;
 use std::path::{Path, PathBuf};
 use tower_lsp::lsp_types;
 
-use crate::utils::include_is_module;
+use crate::utils::{include_is_module, DocumentNormalize};
 use crate::{consts::TREESITTER_CMAKE_LANGUAGE, utils::treehelper::PositionType};
 
 use super::getsubdef;
@@ -87,16 +87,16 @@ pub fn scanner_include_defs(
     include_files: &mut Vec<PathBuf>,
     complete_packages: &mut Vec<String>,
     find_cmake_in_package: bool,
-    is_buildin: bool,
+    is_builtin: bool,
 ) -> Option<Vec<CacheDataUnit>> {
-    if is_buildin {
+    if is_builtin {
         if let Ok(cache) = PACKAGE_COMPLETE_CACHE.lock() {
             if let Some(complete_items) = cache.get(path) {
                 return Some(complete_items.clone());
             }
         }
     }
-    let content = fs::read_to_string(path).ok()?;
+    let content = fs::read_to_string(path).ok()?.normalize();
     let mut parse = tree_sitter::Parser::new();
     parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
     let thetree = parse.parse(&content, None)?;
@@ -110,7 +110,7 @@ pub fn scanner_include_defs(
         true,
         find_cmake_in_package,
     );
-    if !is_buildin {
+    if !is_builtin {
         return result_data;
     }
     if let Some(ref content) = result_data {
@@ -191,7 +191,7 @@ pub fn scanner_package_defs(
             return Some(complete_items.clone());
         }
     }
-    let content = fs::read_to_string(path).ok()?;
+    let content = fs::read_to_string(path).ok()?.normalize();
     let mut parse = tree_sitter::Parser::new();
     parse.set_language(&TREESITTER_CMAKE_LANGUAGE).unwrap();
     let thetree = parse.parse(&content, None)?;
