@@ -10,6 +10,8 @@ use tree_sitter::{Node, Point};
 
 use crate::CMakeNodeKinds;
 
+use super::get_node_content;
+
 const BLACK_POS_STRING: [&str; 5] = ["(", ")", "{", "}", "$"];
 
 const SPECIALCOMMANDS: [&str; 3] = [
@@ -27,6 +29,26 @@ pub fn point_to_position(input: Point) -> Position {
     }
 }
 
+pub trait ToPosition {
+    fn to_position(&self) -> Position;
+}
+
+pub trait ToPoint {
+    fn to_point(&self) -> Point;
+}
+
+impl ToPosition for Point {
+    fn to_position(&self) -> Position {
+        point_to_position(*self)
+    }
+}
+
+impl ToPoint for Position {
+    fn to_point(&self) -> Point {
+        position_to_point(*self)
+    }
+}
+
 /// lsp_types to treesitter
 #[inline]
 pub fn position_to_point(input: Position) -> Point {
@@ -36,8 +58,34 @@ pub fn position_to_point(input: Position) -> Point {
     }
 }
 
+#[test]
+fn test_change() {
+    let point = Point {
+        row: 10,
+        column: 10,
+    };
+    assert_eq!(
+        Position {
+            line: 10,
+            character: 10
+        },
+        point.to_position()
+    );
+    let position = Position {
+        line: 10,
+        character: 10,
+    };
+    assert_eq!(
+        Point {
+            row: 10,
+            column: 10
+        },
+        position.to_point()
+    );
+}
+
 /// get the position of the string
-pub fn get_point_string(location: Point, root: Node, source: &Vec<&str>) -> Option<String> {
+pub fn get_point_string<'a>(location: Point, root: Node, source: &Vec<&'a str>) -> Option<&'a str> {
     let mut course = root.walk();
     for child in root.children(&mut course) {
         if !location_range_contain(location, child) {
@@ -50,7 +98,7 @@ pub fn get_point_string(location: Point, root: Node, source: &Vec<&str>) -> Opti
             let mabepos = get_point_string(location, child, source);
             if mabepos
                 .as_ref()
-                .is_some_and(|message| !BLACK_POS_STRING.contains(&message.as_str()))
+                .is_some_and(|message| !BLACK_POS_STRING.contains(message))
             {
                 return mabepos;
             };
@@ -66,7 +114,7 @@ pub fn get_point_string(location: Point, root: Node, source: &Vec<&str>) -> Opti
 
             let message = &source[h][x..y];
 
-            return Some(message.to_string());
+            return Some(message);
         }
     }
     None
@@ -74,8 +122,7 @@ pub fn get_point_string(location: Point, root: Node, source: &Vec<&str>) -> Opti
 
 /// from the position to get range
 pub fn get_position_range(location: Position, root: Node) -> Option<Range> {
-    let neolocation = position_to_point(location);
-    //let newsource: Vec<&str> = source.lines().collect();
+    let neolocation = location.to_point();
     let mut course = root.walk();
     for child in root.children(&mut course) {
         if !location_range_contain(neolocation, child) {
@@ -96,8 +143,8 @@ pub fn get_position_range(location: Position, root: Node) -> Option<Range> {
             && neolocation.column >= child.start_position().column
         {
             return Some(Range {
-                start: point_to_position(child.start_position()),
-                end: point_to_position(child.end_position()),
+                start: child.start_position().to_position(),
+                end: child.end_position().to_position(),
             });
         }
     }
@@ -120,9 +167,7 @@ pub static MESSAGE_STORAGE: LazyLock<HashMap<String, String>> = LazyLock::new(||
         let content: Vec<_> = re.split(&temp).collect();
         let context = &content[1..];
         for (akey, message) in zip(key, context) {
-            storage
-                .entry(akey.to_string())
-                .or_insert_with(|| message.to_string());
+            storage.insert(akey.to_string(), message.to_string());
         }
     }
     if let Ok(output) = Command::new("cmake").arg("--help-variables").output() {
@@ -138,9 +183,7 @@ pub static MESSAGE_STORAGE: LazyLock<HashMap<String, String>> = LazyLock::new(||
         let content: Vec<_> = re.split(&temp).collect();
         let context = &content[1..];
         for (akey, message) in zip(key, context) {
-            storage
-                .entry(akey.to_string())
-                .or_insert_with(|| message.to_string());
+            storage.insert(akey.to_string(), message.to_string());
         }
     }
     if let Ok(output) = Command::new("cmake").arg("--help-modules").output() {
@@ -156,21 +199,21 @@ pub static MESSAGE_STORAGE: LazyLock<HashMap<String, String>> = LazyLock::new(||
         let content: Vec<_> = re.split(&temp).collect();
         let context = &content[1..];
         for (akey, message) in zip(key, context) {
-            storage
-                .entry(akey.to_string())
-                .or_insert_with(|| message.to_string());
+            storage.insert(akey.to_string(), message.to_string());
         }
     }
     #[cfg(unix)]
-    storage
-        .entry("pkg_check_modules".to_string())
-        .or_insert_with(|| "please FindPackage PkgConfig first".to_string());
+    storage.insert(
+        "pkg_check_modules".to_string(),
+        "please FindPackage PkgConfig first".to_string(),
+    );
     storage
 });
 
 #[derive(Clone, Copy, Debug, PartialEq, Eq)]
 pub enum PositionType<'a> {
-    VarOrFun,       // the variable defined in cmake file or macro or fun
+    VarOrFun, // the variable defined in cmake file or macro or fun
+    FunOrMacroIdentifier,
     ArgumentOrList, // Not the ${abc} kind, just normake argument
     FindPackage,    // normal_command start with find_package
     FindPackageSpace(&'a str),
@@ -178,6 +221,7 @@ pub enum PositionType<'a> {
     FindPkgConfig, // PkgConfig file
     SubDir,
     Include,
+    FunOrMacroArgs,
     Unknown, // Unknown type, use as the input
     TargetInclude,
     TargetLink,
@@ -266,16 +310,32 @@ fn get_pos_type_inner<'a>(
                 }
             }
             CMakeNodeKinds::ARGUMENT_LIST => {
-                if child.child_count() >= 2 && input_type == PositionType::FindPackage {
+                let child_count = child.child_count();
+                if child.child_count() >= 1 {
                     let first_argument = child.child(0).unwrap();
                     let row = first_argument.start_position().row;
                     let col_x = first_argument.start_position().column;
                     let col_y = first_argument.end_position().column;
+                    let node_source = get_node_content(source, &child);
                     let val = &source[row][col_x..col_y];
-                    return PositionType::FindPackageSpace(val);
+                    if child_count >= 2
+                        && !location_range_contain(location, first_argument)
+                        && input_type == PositionType::FindPackage
+                        && node_source.iter().any(|context| *context == "COMPONENTS")
+                    {
+                        return PositionType::FindPackageSpace(val);
+                    }
+                    if input_type == PositionType::FunOrMacroArgs
+                        && location_range_contain(location, first_argument)
+                    {
+                        return PositionType::FunOrMacroIdentifier;
+                    }
                 }
                 PositionType::ArgumentOrList
             }
+            CMakeNodeKinds::FUNCTION_COMMAND | CMakeNodeKinds::MACRO_COMMAND => {
+                PositionType::FunOrMacroArgs
+            }
             CMakeNodeKinds::UNQUOTED_ARGUMENT | CMakeNodeKinds::QUOTED_ELEMENT => {
                 PositionType::ArgumentOrList
             }
@@ -335,11 +395,16 @@ fn get_pos_type_inner<'a>(
                         _ => return currenttype,
                     };
                 }
-                PositionType::Unknown | PositionType::Comment | PositionType::ArgumentOrList => {
-                    return get_pos_type_inner(location, child, source, input_type)
+                PositionType::Unknown
+                | PositionType::Comment
+                | PositionType::ArgumentOrList
+                | PositionType::FunOrMacroArgs => {
+                    return get_pos_type_inner(location, child, source, jumptype)
                 }
                 // NOTE: it should be designed to cannot be reach
-                PositionType::FindPackageSpace(_) => unreachable!(),
+                PositionType::FindPackageSpace(_) | PositionType::FunOrMacroIdentifier => {
+                    unreachable!()
+                }
             }
         } else {
             // if is the same line
@@ -410,6 +475,9 @@ include("abcd/efg.cmake")
 test, here is BRACKET_COMMENT
 ]]#
 find_package(Qt5 COMPONENTS Core)
+find_package(Qt5Core CONFIG)
+macro(macro_test)
+endmacro()
     "#;
     use crate::consts::TREESITTER_CMAKE_LANGUAGE;
     let mut parse = tree_sitter::Parser::new();
@@ -425,6 +493,10 @@ find_package(Qt5 COMPONENTS Core)
         get_pos_type(Point { row: 2, column: 4 }, input, source,),
         PositionType::VarOrFun
     );
+    assert_eq!(
+        get_pos_type(Point { row: 3, column: 5 }, input, source,),
+        PositionType::VarOrFun
+    );
     assert_eq!(
         get_pos_type(Point { row: 5, column: 15 }, input, source,),
         PositionType::FindPackage
@@ -475,5 +547,31 @@ find_package(Qt5 COMPONENTS Core)
             source,
         ),
         PositionType::FindPackageSpace("Qt5")
+    );
+    assert_eq!(
+        get_pos_type(
+            Point {
+                row: 15,
+                column: 15
+            },
+            input,
+            source,
+        ),
+        PositionType::FindPackage
+    );
+    assert_eq!(
+        get_pos_type(
+            Point {
+                row: 16,
+                column: 21
+            },
+            input,
+            source,
+        ),
+        PositionType::FindPackage
+    );
+    assert_eq!(
+        get_pos_type(Point { row: 17, column: 8 }, input, source,),
+        PositionType::FunOrMacroIdentifier
     )
 }
